Affected by GO-2023-1986
and 20 other vulnerabilities
GO-2023-1986 : HashiCorp Vault and Vault Enterprise vulnerable to user enumeration in github.com/hashicorp/vault
GO-2023-2088 : Hashicorp Vault Incorrect Permission Assignment for Critical Resource vulnerability in github.com/hashicorp/vault
GO-2023-2329 : HashiCorp Vault Missing Release of Memory after Effective Lifetime vulnerability in github.com/hashicorp/vault
GO-2024-2617 : Authentication bypass in github.com/hashicorp/vault
GO-2024-2690 : HashiCorpVault does not correctly validate OCSP responses in github.com/hashicorp/vault
GO-2024-2921 : HashiCorp Vault Incorrectly Validated JSON Web Tokens (JWT) Audience Claims in github.com/hashicorp/vault
GO-2024-2982 : Hashicorp Vault vulnerable to Improper Check or Handling of Exceptional Conditions in github.com/hashicorp/vault
GO-2024-3162 : Vault SSH Secrets Engine Configuration Did Not Restrict Valid Principals By Default in github.com/hashicorp/vault
GO-2024-3191 : Vault Community Edition privilege escalation vulnerability in github.com/hashicorp/vault
GO-2024-3246 : Hashicorp Vault vulnerable to denial of service through memory exhaustion in github.com/hashicorp/vault
GO-2025-3662 : Hashicorp Vault Community vulnerable to Incorrect Authorization in github.com/hashicorp/vault
GO-2025-3663 : Hashicorp Vault Community vulnerable to Generation of Error Message Containing Sensitive Information in github.com/hashicorp/vault
GO-2025-3836 : Hashicorp Vault has Incorrect Validation for Non-CA Certificates in github.com/hashicorp/vault
GO-2025-3837 : Hashicorp Vault has Privilege Escalation Vulnerability in github.com/hashicorp/vault
GO-2025-3838 : Hashicorp Vault has Code Execution Vulnerability via Plugin Configuration in github.com/hashicorp/vault
GO-2025-3839 : Hashicorp Vault has an Observable Discrepancy on Existing and Non-Existing Users in github.com/hashicorp/vault
GO-2025-3841 : Hashicorp Vault's TOTP Secrets Engine Susceptible to Code Reuse in github.com/hashicorp/vault
GO-2025-3842 : Hashicorp Vault has Login MFA Rate Limit Bypass Vulnerability in github.com/hashicorp/vault
GO-2025-3848 : HashiCorp Vault ldap auth method may not have correctly enforced MFA in github.com/hashicorp/vault
GO-2025-3924 : HashiCorp Vault Community Edition Denial of Service Though Complex JSON Payloads in github.com/hashicorp/vault
GO-2025-4070 : HashiCorp Vault and Vault Enterprise's AWS Auth method may be susceptible to authentication bypass in github.com/hashicorp/vault
Discover Packages
github.com/hashicorp/vault
helper
fairshare
package
Version:
v1.13.0-rc1
Opens a new window with list of versions in this module.
Published: Feb 13, 2023
License: MPL-2.0
Opens a new window with license information.
Imports: 12
Opens a new window with list of imports.
Imported by: 3
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Job interface {
Execute() error
OnFailure(err error )
}
Job is an interface for jobs used with this job manager
type JobManager struct {
}
NewJobManager creates a job manager, with an optional name
AddJob adds a job to the given queue, creating the queue if it doesn't exist
GetCurrentJobCount returns the total number of pending jobs in the job manager
GetWorkQueueLengths() returns a map of queue ID to number of jobs in the queue
GetWorkerCounts() returns a map of queue ID to number of active workers
Start starts the job manager
note: a given job manager cannot be restarted after it has been stopped
Stop stops the job manager asynchronously
Source Files
¶
Click to show internal directories.
Click to hide internal directories.